pub struct AuthorityOverloadConfig {
pub max_txn_age_in_queue: Duration,
pub overload_monitor_interval: Duration,
pub execution_queue_latency_soft_limit: Duration,
pub execution_queue_latency_hard_limit: Duration,
pub max_load_shedding_percentage: u32,
pub min_load_shedding_percentage_above_hard_limit: u32,
pub safe_transaction_ready_rate: u32,
pub check_system_overload_at_signing: bool,
pub check_system_overload_at_execution: bool,
pub max_transaction_manager_queue_length: usize,
pub max_transaction_manager_per_object_queue_length: usize,
pub max_transaction_manager_queue_length_soft_limit_pct: u32,
}Expand description
Configuration for the threshold(s) at which we consider the system to be overloaded. When one of the threshold is passed, the node may stop processing new transactions and/or certificates until the congestion resolves.
Fields
max_txn_age_in_queue: DurationMaximum time a transaction can wait in the transaction manager execution queue before it triggers an overload detection on the object it depends on.
overload_monitor_interval: DurationThe interval of checking overload signal.
execution_queue_latency_soft_limit: DurationThe execution queueing latency when entering load shedding mode.
execution_queue_latency_hard_limit: DurationThe execution queueing latency when entering aggressive load shedding mode.
max_load_shedding_percentage: u32The maximum percentage of transactions to shed in load shedding mode.
min_load_shedding_percentage_above_hard_limit: u32When in aggressive load shedding mode, the minimum percentage of transactions to shed.
safe_transaction_ready_rate: u32If transaction ready rate is below this rate, we consider the validator is well under used, and will not enter load shedding mode.
check_system_overload_at_signing: boolWhen set to true, transaction signing may be rejected when the validator is overloaded.
check_system_overload_at_execution: boolWhen set to true, transaction execution may be rejected when the validator is overloaded.
max_transaction_manager_queue_length: usizeReject a transaction if transaction manager queue length is above this threshold. 100_000 = 10k TPS * 5s resident time in transaction manager (pending + executing) * 2.
max_transaction_manager_per_object_queue_length: usizeReject a transaction if the number of pending transactions depending on the object is above the threshold.
max_transaction_manager_queue_length_soft_limit_pct: u32Percentage of max_transaction_manager_queue_length at which graduated
load shedding begins in the certificate-less (P-COOL) mode. Read
via the same-named accessor, which clamps the value to <=100.
Implementations
Sourceimpl AuthorityOverloadConfig
impl AuthorityOverloadConfig
Sourcepub fn max_transaction_manager_queue_length_soft_limit_pct(&self) -> u32
pub fn max_transaction_manager_queue_length_soft_limit_pct(&self) -> u32
Returns the soft-limit percentage, clamped to <=100 to guard against out-of-range operator-supplied values.