pub struct ConsensusConfig {
pub db_path: PathBuf,
pub db_retention_epochs: Option<u64>,
pub db_pruner_period_secs: Option<u64>,
pub max_pending_transactions: Option<usize>,
pub max_submit_position: Option<usize>,
pub submit_delay_step_override_millis: Option<u64>,
pub parameters: Option<Parameters>,
pub graduated_load_shedding_soft_limit_pct: Option<u32>,
}Fields
db_path: PathBufBase consensus DB path for all epochs.
db_retention_epochs: Option<u64>The number of epochs for which to retain the consensus DBs. Setting it to 0 will make a consensus DB getting dropped as soon as system is switched to a new epoch.
db_pruner_period_secs: Option<u64>Pruner will run on every epoch change but it will also check
periodically on every db_pruner_period_secs seconds to see
if there are any epoch DBs to remove.
max_pending_transactions: Option<usize>Hard limit on the number of pending transactions to submit to
consensus, including those in submission wait. Used as the upper
bound for graduated pre-consensus load shedding
(graduated_load_shedding_soft_limit_pct) in the certificate-less
(P-COOL) mode, and as the threshold for the binary
cutoff in ConsensusAdapter::check_consensus_overload() in both
certificate-less and certificate-based flows.
Default to 20_000 inflight limit, assuming 20_000 txn tps * 1 sec consensus latency.
max_submit_position: Option<usize>When defined caps the calculated submission position to the max_submit_position.
Even if the is elected to submit from a higher position than this, it will “reset” to the max_submit_position.
submit_delay_step_override_millis: Option<u64>The submit delay step to consensus defined in milliseconds.
When provided it will override the current back off logic otherwise the default backoff logic will be applied based on consensus latency estimates.
parameters: Option<Parameters>Parameters for Starfish consensus
graduated_load_shedding_soft_limit_pct: Option<u32>Percentage of max_pending_transactions (hard limit) defining the soft
limit at which graduated pre-consensus load shedding begins. When
in-flight transactions are at or below the soft limit, no shedding
occurs; above it, the shedding rate scales linearly from 0% to 100% at
max_pending_transactions. Used in the certificate-less (P-COOL) mode.
Implementations
Sourceimpl ConsensusConfig
impl ConsensusConfig
pub fn db_path(&self) -> &Path
Sourcepub fn max_pending_transactions(&self) -> usize
pub fn max_pending_transactions(&self) -> usize
Returns the hard limit on the number of pending transactions to submit to consensus, including those in submission wait. Defaults to 20_000 inflight limit, assuming 20_000 txn tps * 1 sec consensus latency.
Sourcepub fn graduated_load_shedding_soft_limit_pct(&self) -> u32
pub fn graduated_load_shedding_soft_limit_pct(&self) -> u32
Returns the percentage of max_pending_transactions (hard limit)
defining the soft limit at which graduated pre-consensus load
shedding begins. Defaults to 50%. Used in the certificate-less
(P-COOL) mode.
pub fn submit_delay_step_override(&self) -> Option<Duration>
pub fn db_retention_epochs(&self) -> u64
pub fn db_pruner_period(&self) -> Duration