pub struct GrpcApiConfig {
pub address: SocketAddr,
pub tls: Option<TlsConfig>,
pub max_message_size_bytes: u32,
pub broadcast_buffer_size: u32,
pub max_json_move_value_size: usize,
pub max_execute_transaction_batch_size: u32,
pub max_simulate_transaction_batch_size: u32,
pub max_checkpoint_inclusion_timeout_ms: u64,
}Expand description
Configuration for the gRPC API service
Fields
address: SocketAddrThe address to bind the gRPC server to
tls: Option<TlsConfig>TLS configuration for the gRPC server.
If not provided, the gRPC server will use plain TCP without TLS.
max_message_size_bytes: u32Maximum message size for gRPC responses (in bytes)
broadcast_buffer_size: u32Buffer size for broadcast channels used for streaming
max_json_move_value_size: usizeMaximum size for Move values when rendering to JSON in bytes.
max_execute_transaction_batch_size: u32Maximum number of transactions allowed in a single ExecuteTransactions batch request.
max_simulate_transaction_batch_size: u32Maximum number of transactions allowed in a single SimulateTransactions batch request.
max_checkpoint_inclusion_timeout_ms: u64Maximum allowed timeout in milliseconds for waiting for checkpoint inclusion in ExecuteTransactions requests. Client-specified timeouts are clamped to this value.
Implementations
Sourceimpl GrpcApiConfig
impl GrpcApiConfig
pub fn tls_config(&self) -> Option<&TlsConfig>
pub fn max_message_size_bytes(&self) -> u32
Sourcepub fn max_message_size_client_bytes(
&self,
client_max_message_size_bytes: Option<u32>,
) -> u32
pub fn max_message_size_client_bytes( &self, client_max_message_size_bytes: Option<u32>, ) -> u32
Calculate the maximum size for a message that can be sent to a client, taking into account the client’s max message size preference.