pub struct NodeConfig {Show 46 fields
pub authority_key_pair: AuthorityKeyPairWithPath,
pub protocol_key_pair: KeyPairWithPath,
pub account_key_pair: KeyPairWithPath,
pub network_key_pair: KeyPairWithPath,
pub db_path: PathBuf,
pub network_address: Multiaddr,
pub json_rpc_address: SocketAddr,
pub metrics_address: SocketAddr,
pub admin_interface_address: SocketAddr,
pub consensus_config: Option<ConsensusConfig>,
pub enable_index_processing: bool,
pub jsonrpc_server_type: Option<ServerType>,
pub grpc_load_shed: Option<bool>,
pub grpc_concurrency_limit: Option<usize>,
pub p2p_config: P2pConfig,
pub genesis: Genesis,
pub migration_tx_data_path: Option<PathBuf>,
pub authority_store_pruning_config: AuthorityStorePruningConfig,
pub end_of_epoch_broadcast_channel_capacity: usize,
pub checkpoint_executor_config: CheckpointExecutorConfig,
pub metrics: Option<MetricsConfig>,
pub supported_protocol_versions: Option<SupportedProtocolVersions>,
pub db_checkpoint_config: DBCheckpointConfig,
pub expensive_safety_check_config: ExpensiveSafetyCheckConfig,
pub transaction_deny_config: TransactionDenyConfig,
pub certificate_deny_config: CertificateDenyConfig,
pub state_debug_dump_config: StateDebugDumpConfig,
pub state_archive_write_config: StateArchiveConfig,
pub state_archive_read_config: Vec<StateArchiveConfig>,
pub state_snapshot_write_config: StateSnapshotConfig,
pub indexer_max_subscriptions: Option<usize>,
pub transaction_kv_store_read_config: TransactionKeyValueStoreReadConfig,
pub transaction_kv_store_write_config: Option<TransactionKeyValueStoreWriteConfig>,
pub authority_overload_config: AuthorityOverloadConfig,
pub run_with_range: Option<RunWithRange>,
pub policy_config: Option<PolicyConfig>,
pub firewall_config: Option<RemoteFirewallConfig>,
pub execution_cache_config: ExecutionCacheConfig,
pub enable_validator_tx_finalizer: bool,
pub verifier_signing_config: VerifierSigningConfig,
pub enable_db_write_stall: Option<bool>,
pub iota_names_config: Option<IotaNamesConfig>,
pub enable_grpc_api: bool,
pub grpc_api_config: Option<GrpcApiConfig>,
pub chain_override_for_testing: Option<Chain>,
pub validator_client_monitor_config: Option<ValidatorClientMonitorConfig>,
}Fields
The public key bytes corresponding to the private key that the validator holds to sign transactions.
protocol_key_pair: KeyPairWithPathThe public key bytes corresponding to the private key that the validator holds to sign consensus blocks.
account_key_pair: KeyPairWithPathnetwork_key_pair: KeyPairWithPathThe public key bytes corresponding to the private key that the validator uses to establish TLS connections.
db_path: PathBufnetwork_address: MultiaddrThe network address for gRPC communication.
Can be overwritten with args listen-address parameters.
json_rpc_address: SocketAddrmetrics_address: SocketAddrThe address for Prometheus metrics.
admin_interface_address: SocketAddrThe address for the admin interface that is run in the metrics separate runtime and provides access to admin node commands such as logging and tracing options.
consensus_config: Option<ConsensusConfig>Configuration struct for the consensus.
enable_index_processing: boolFlag to enable index processing for a full node.
If set to true, node creates IndexStore for transaction
data including ownership and balance information.
jsonrpc_server_type: Option<ServerType>Determines the jsonrpc server type as either:
- ‘websocket’ for a websocket based service (deprecated)
- ‘http’ for an http based service
- ‘both’ for both a websocket and http based service (deprecated)
grpc_load_shed: Option<bool>Flag to enable gRPC load shedding to manage and
mitigate overload conditions by shedding excess
load with LoadShedLayer middleware.
grpc_concurrency_limit: Option<usize>p2p_config: P2pConfigConfiguration struct for P2P.
genesis: GenesisContains genesis location that might be InPlace
for reading all genesis data to memory or InFile,
and OnceCell pointer to a genesis struct.
migration_tx_data_path: Option<PathBuf>Contains the path where to find the migration blob.
Configuration for pruning of the authority store, to define when an old data is removed from the storage space.
end_of_epoch_broadcast_channel_capacity: usizeSize of the broadcast channel used for notifying other systems of end of epoch.
If unspecified, this will default to 128.
checkpoint_executor_config: CheckpointExecutorConfigConfiguration for the checkpoint executor for limiting the number of checkpoints to execute concurrently, and to allow for checkpoint post-processing.
metrics: Option<MetricsConfig>supported_protocol_versions: Option<SupportedProtocolVersions>In a iota-node binary, this is set to
SupportedProtocolVersions::SYSTEM_DEFAULT in iota-node/src/main.rs.
It is present in the config so that it can be changed by tests in
order to test protocol upgrades.
db_checkpoint_config: DBCheckpointConfigConfiguration to manage database checkpoints, including whether to perform checkpoints at the end of an epoch, the path for storing checkpoints, and other related settings.
expensive_safety_check_config: ExpensiveSafetyCheckConfigConfiguration for enabling/disabling expensive safety checks.
transaction_deny_config: TransactionDenyConfigConfiguration to specify rules for denying transactions
based on objectsIDs, addresses, or enable/disable many
features such as publishing new packages or using shared objects.
certificate_deny_config: CertificateDenyConfigConfig used to deny execution for certificate digests know for crashing or hanging validator nodes.
Should be used for a fast temporary fixes and removed once the issue is fixed.
state_debug_dump_config: StateDebugDumpConfigUsed to determine how state debug information is dumped when a node forks.
state_archive_write_config: StateArchiveConfigConfiguration for writing state archive. If ObjectStorage
config is provided, ArchiveWriter will be created
for checkpoints archival.
state_archive_read_config: Vec<StateArchiveConfig>state_snapshot_write_config: StateSnapshotConfigDetermines if snapshot should be uploaded to the remote storage.
indexer_max_subscriptions: Option<usize>transaction_kv_store_read_config: TransactionKeyValueStoreReadConfigtransaction_kv_store_write_config: Option<TransactionKeyValueStoreWriteConfig>Configuration for defining thresholds and settings for managing system overload conditions in a node.
run_with_range: Option<RunWithRange>Specifies the ending epoch for a node for debugging purposes.
Ignored if set by config, can be configured only by cli arguments.
policy_config: Option<PolicyConfig>firewall_config: Option<RemoteFirewallConfig>execution_cache_config: ExecutionCacheConfigenable_validator_tx_finalizer: boolverifier_signing_config: VerifierSigningConfigenable_db_write_stall: Option<bool>If a value is set, it determines if writes to DB can stall, which can halt the whole process. By default, write stall is enabled on validators but not on fullnodes.
iota_names_config: Option<IotaNamesConfig>enable_grpc_api: boolFlag to enable the gRPC API.
grpc_api_config: Option<GrpcApiConfig>chain_override_for_testing: Option<Chain>Allow overriding the chain for testing purposes. For instance, it allows you to create a test network that believes it is mainnet or testnet. Attempting to override this value on production networks will result in an error.
validator_client_monitor_config: Option<ValidatorClientMonitorConfig>Configuration for the validator client monitor that tracks client-observed performance metrics for validators.
Implementations
Sourceimpl NodeConfig
impl NodeConfig
pub fn protocol_key_pair(&self) -> &NetworkKeyPair
pub fn network_key_pair(&self) -> &NetworkKeyPair
pub fn db_path(&self) -> PathBuf
pub fn db_checkpoint_path(&self) -> PathBuf
pub fn archive_path(&self) -> PathBuf
pub fn snapshot_path(&self) -> PathBuf
pub fn network_address(&self) -> &Multiaddr
pub fn consensus_config(&self) -> Option<&ConsensusConfig>
pub fn genesis(&self) -> Result<&Genesis>
pub fn load_migration_tx_data(&self) -> Result<MigrationTxData>
pub fn iota_address(&self) -> IotaAddress
pub fn archive_reader_config(&self) -> Vec<ArchiveReaderConfig>
pub fn jsonrpc_server_type(&self) -> ServerType